// Clipboard.js


// gets string of clipboard contents
function getClipboard() {
  var url;

  try {
    var clipboard = Components.classes["@mozilla.org/widget/clipboard;1"]                            .getService(Components.interfaces.nsIClipboard);

    // Create tranferable that will transfer the text.
    var trans = Components.classes["@mozilla.org/widget/transferable;1"]
      .createInstance(Components.interfaces.nsITransferable);

    trans.addDataFlavor("text/unicode");
    clipboard.getData(trans, clipboard.kSelectionClipboard);

    var data = {};
    var dataLen = {};
    trans.getTransferData("text/unicode", data, dataLen);

    if (data) {
        data = data.value.QueryInterface(Components.interfaces.nsISupportsString);
    }
    if (data) {
        url = data.data.substring(0, dataLen.value / 2);
    }
  } catch (ex) {
    dump("Caught an exception in navigator.js, getClipboard(): " + ex + "\n");
    return "";
  }
  return url;
}

function undoClipboard() {
    goDoCommand("cmd_undo");
}



function copyToClipboard(string) {
    var str = Components.classes["@mozilla.org/supports-string;1"].
    createInstance(Components.interfaces.nsISupportsString);

    if (!str) return false;
    str.data=string;

    var trans = Components.classes["@mozilla.org/widget/transferable;1"].
    createInstance(Components.interfaces.nsITransferable);

    if (!trans) return false;

    trans.addDataFlavor("text/unicode");
    trans.setTransferData("text/unicode",str,string.length*2);

    var clipid=Components.interfaces.nsIClipboard;
    var clip = Components.classes["@mozilla.org/widget/clipboard;1"].getService(clipid);
    if (!clip) return false;

    clip.setData(trans,null,clipid.kGlobalClipboard);
}


// inserts tags into editor pane
function insertTagLogic(beginTag, endTag) {
    var start = content.selectionStart;
    var end = content.selectionEnd;
    var backupString = getClipboard();

    if (start == end) {
        var string = "";
    } else {
        var strContent = content.value;
        var string = strContent.substr(start,end - start);
    }

    copyToClipboard(beginTag + string + endTag);
    content.focus();
    goDoCommand("cmd_paste");
    copyToClipboard(backupString);
}

// insert character functions for editing
function insertComment() {
    var start = content.selectionStart;
    var end = content.selectionEnd;

    if (start == end) {
        return;
    } else {
        var string = content.value.substr(start,end - start);
    }

    var list = string.split("\n");

    for (x=0; x < list.length; x++) {
        list[x] = "//" + list[x];
    }
    list = list.join("\n");

    var backupString = getClipboard();

    goDoCommand("cmd_copy");
    copyToClipboard(list);
    content.focus();
    goDoCommand("cmd_paste");
    copyToClipboard(backupString);
}

function insertUncomment() {
    var start = content.selectionStart;
    var end = content.selectionEnd;

    if (start == end) {
        return;
    } else {
        var string = content.value.substr(start,end - start);
    }

    var list = string.split("\n");

    for (x=0; x < list.length; x++) {
        list[x] = list[x].replace(/\/\//,"");
    }
    list = list.join("\n");

    var backupString = getClipboard();

    goDoCommand("cmd_copy");
    copyToClipboard(list);
    content.focus();
    goDoCommand("cmd_paste");
    copyToClipboard(backupString);
}

function insertIndent() {
    var start = content.selectionStart;
    var end = content.selectionEnd;

    if (start == end) {
        var string = "";
    } else {
        var string = content.value.substr(start,end - start);
    }

    var list = string.split("\n");
    var tab = "";

    for (x=0; x < tabSize; x++){
        tab = tab + " ";
    }

    for (x=0; x < list.length; x++) {
        list[x] = tab + list[x];
    }
    list = list.join("\n");

    var backupString = getClipboard();

    goDoCommand("cmd_copy");
    copyToClipboard(list);
    content.focus();
    goDoCommand("cmd_paste");
    copyToClipboard(backupString);
}


function insertUnindent() {
    var start = content.selectionStart;
    var end = content.selectionEnd;

    if (start == end) {
        return;
    } else {
        var string = content.value.substr(start,end - start);
    }

    var list = string.split("\n");

    for (x=0; x < list.length; x++) {
        var pattern = new RegExp("^\\s{2}");
        list[x] = list[x].replace(pattern,"");
    }

    list = list.join("\n");

    var backupString = getClipboard();

    goDoCommand("cmd_copy");
    copyToClipboard(list);
    content.focus();
    goDoCommand("cmd_paste");
    copyToClipboard(backupString);
}


function insertTagAnchor() {
    insertTagLogic("<a href=\"\" title=\"\">","</a>");
}


function insertTagSub() {
    insertTagLogic("<sub>","</sub>");
}

function insertTagSup() {
    insertTagLogic("<sup>","</sup>");
}

function insertTagUnderline() {
    if (isCssEnabled == "true") {
        insertTagLogic("<span style='text-decoration: underline;'>","</span>");
    } else {
        insertTagLogic("<u>","</u>");
    }
}

function insertTagStrikethrough() {
    insertTagLogic("<span style='text-decoration: line-through;'>","</span>");
}

function insertTagBold() {
    if (isCssEnabled == "true") {
        insertTagLogic("<span style='font-weight: bold;'>","</span>");
    } else {
        insertTagLogic("<b>","</b>");
    }
}

function insertTagItalics() {
    if (isCssEnabled == "true") {
        insertTagLogic("<span style='font-style: italic;'>","</span>");
    } else {
        insertTagLogic("<i>","</i>");
    }
}

function insertTagParagraph() {
    insertTagLogic("<p>","</p>");
}

function insertTagSpan() {
    insertTagLogic("<span>","</span>");
}

function insertTagDiv() {
    insertTagLogic("<div>","</div>");
}

function insertTagCenter() {
    if (isCssEnabled == "true") {
        insertTagLogic("<div style='text-align: center;'>","</div>");
    } else {
        insertTagLogic("<center>","</center>");
    }
}

function insertTagComment() {
    insertTagLogic("<!--","-->");
}

function pasteText(text) {
    var backupString = getClipboard();

    copyToClipboard(text);
    content.focus();
    goDoCommand("cmd_paste");
    copyToClipboard(backupString);
}

function insertTab() {
    var backupString = getClipboard();
    var tab = "";
    for (x=0; x < tabSize; x++){
        tab = tab + " ";
    }

    copyToClipboard(tab);
    content.focus();
    goDoCommand("cmd_paste");
    copyToClipboard(backupString);
}

function insertTagSpace() {
    var backupString = getClipboard();
    copyToClipboard("&nbsp;");
    content.focus();
    goDoCommand("cmd_paste");
    copyToClipboard(backupString);
}

function insertTagBreak() {
    var backupString = getClipboard();
    if (documentType == "html") {
        copyToClipboard("<br>");
    } else {
         copyToClipboard("<br />");
    }
    content.focus();
    goDoCommand("cmd_paste");
    copyToClipboard(backupString);
}


function insertTagImage() {
    var backupString = getClipboard();
    if (documentType == "html") {
        copyToClipboard("<img src=\"\" alt=\"\">");;
    } else {
        copyToClipboard("<img src=\"\" alt=\"\" />");
    }
    content.focus();
    goDoCommand("cmd_paste");
    copyToClipboard(backupString);
}


function cutClipboard() {
    goDoCommand("cmd_cut");
}

function copyClipboard() {
    goDoCommand("cmd_copy");
}

function pasteClipboard() {
    goDoCommand("cmd_paste");
}

function undoClipboard() {
    goDoCommand("cmd_undo");
}

function insertTagTable() {
    var backupString = getClipboard();
    var string = "<table>\n"+
    "<tr>\n"+
    "  <td>&nbsp;</td>\n"+
    "</tr>\n"+
    "</table>";
    copyToClipboard(string)
    content.focus();
    goDoCommand("cmd_paste");
    copyToClipboard(backupString);
}

function insertSymbol(number) {
    var backupString = getClipboard();
    var symbolStr = String.fromCharCode(number);
    var symbol = "&#" + number + ";";
    switch (number) {
        case 169:
            symbol = "&copy;"
            break;
        case 174:
            symbol = "&reg;"
            break;
        case 32:
            symbol = "&nbsp;"
            break;
        case 34:
            symbol = "&quot;"
            break;
        case 38:
            symbol = "&amp;"
            break;
        case 60:
            symbol = "&lt;"
            break;
        case 62:
            symbol = "&gt;"
            break;
        case 192:
            symbol = "&Agrave;"
            break;
        case 193:
            symbol = "&Aacute;"
            break;
        case 194:
            symbol = "&Acirc;"
            break;
        case 195:
            symbol = "&Atilde;"
            break;
        case 196:
            symbol = "&Auml;"
            break;
        case 197:
            symbol = "&Aring;"
            break;
        case 198:
            symbol = "&AElig;"
            break;
        case 199:
            symbol = "&Ccedil;"
            break;
        case 200:
            symbol = "&Egrave;"
            break;
        case 201:
            symbol = "&Eacute;"
            break;
        case 202:
            symbol = "&Ecirc;"
            break;
        case 203:
            symbol = "&Euml;"
            break;
        case 204:
            symbol = "&lgrave;"
            break;
        case 205:
            symbol = "&lacute;"
            break;
        case 206:
            symbol = "&lcirc;"
            break;
        case 207:
            symbol = "&luml;"
            break;
        case 208:
            symbol = "&ETH;"
            break;
        case 209:
            symbol = "&Ntilde;"
            break;
        case 210:
            symbol = "&Ograve;"
            break;
        case 211:
            symbol = "&Oacute;"
            break;
        case 212:
            symbol = "&Ocirc;"
            break;
        case 213:
            symbol = "&Otilde;"
            break;
        case 214:
            symbol = "&Ouml;"
            break;
        case 216:
            symbol = "&Oslash;"
            break;
        case 217:
            symbol = "&Ugrave;"
            break;
        case 218:
            symbol = "&Uacute;"
            break;
        case 219:
            symbol = "&Ucirc;"
            break;
        case 220:
            symbol = "&Uuml;"
            break;
        case 221:
            symbol = "&Yacute;"
            break;
        case 222:
            symbol = "&THORN;"
            break;
        case 223:
            symbol = "&szlig;"
            break;
        case 224:
            symbol = "&agrave;"
            break;
        case 225:
            symbol = "&aacute;"
            break;
        case 226:
            symbol = "&acirc;"
            break;
        case 227:
            symbol = "&atilde;"
            break;
        case 228:
            symbol = "&auml;"
            break;
        case 229:
            symbol = "&aring;"
            break;
        case 230:
            symbol = "&aelig;"
            break;
        case 231:
            symbol = "&ccedil;"
            break;
        case 232:
            symbol = "&egrave;"
            break;
        case 233:
            symbol = "&eacute;"
            break;
        case 234:
            symbol = "&ecirc;"
            break;
        case 235:
            symbol = "&euml;"
            break;
        case 236:
            symbol = "&igrave;"
            break;
        case 237:
            symbol = "&iacute;"
            break;
        case 238:
            symbol = "&icirc;"
            break;
        case 239:
            symbol = "&iuml;"
            break;
        case 240:
            symbol = "&eth;"
            break;
        case 241:
            symbol = "&ntilde;"
            break;
        case 242:
            symbol = "&ograve;"
            break;
        case 243:
            symbol = "&oacute;"
            break;
        case 244:
            symbol = "&ocirc;"
            break;
        case 245:
            symbol = "&otilde;"
            break;
        case 246:
            symbol = "&ouml;"
            break;
        case 248:
            symbol = "&oslash;"
            break;
        case 249:
            symbol = "&ugrave;"
            break;
        case 250:
            symbol = "&uacute;"
            break;
        case 251:
            symbol = "&ucirc;"
            break;
        case 252:
            symbol = "&uuml;"
            break;
        case 253:
            symbol = "&yacute;"
            break;
        case 254:
            symbol = "&thorn;"
            break;
        case 255:
            symbol = "&yuml;"
            break;
    }


    copyToClipboard(symbol);
    content.focus();
    goDoCommand("cmd_paste");
    copyToClipboard(backupString);
    updateStatus("Inserted symbol: "+symbolStr + " keycode: "+ number);
}

