// EditingFunctions.js


// clear all document text
function clear() {
    content.focus();
    goDoCommand("cmd_selectAll");
    goDoCommand("cmd_cut");
    updateStatus("Content cleared...");
}

// sort box
function changeSort() {
  // get the box to sort
  var box = document.getElementById("info");

  // if the sort direction is descending, change it to ascending.
  // Otherwise, set it to ascending.
  if (box.getAttribute("sortDirection") == "descending")
    box.setAttribute("sortDirection","ascending");
  else box.setAttribute("sortDirection","descending");

  // you must rebuild the content after changing sort information
  box.builder.rebuild();
}


function scrollTo(strFunction) {
    try {
        var modified = buffer.getIsChanged();
        doFind(strFunction,"i");
        goDoCommand("cmd_scrollLineUp");
        buffer.setIsChanged(modified)
    } catch(e) {
        dump(e + "error in editingfunctions:scrolTo()\n");
    }
}


var lastFindIndex = 0;
var lastFindStr = "";
var lastFindIgnoreCase = "";

function doFindAgain() {
    if (lastFindStr == "") {
        updateStatus("Find again... Nothing to find. Select Find first.");
        return;
    }

    var subStr = content.value.substr(lastFindIndex, content.value.length-1);
    ignoreCaseStr = "";

    contentStr = subStr;
    ignoreCaseStr = lastFindIgnoreCase;
    findStr = lastFindStr;

    var pattern = new RegExp(findStr, ignoreCaseStr);
    var searchResult = contentStr.search(pattern);
    //alert("search: "+searchResult+"  lasIndex: "+lastFindIndex)

    if (searchResult != -1 ) {
        content.select();
        content.setSelectionRange(searchResult+lastFindIndex, searchResult+lastFindIndex + findStr.length);

        // copy, paste is scrollTo hack in textbox
        var backupString = getClipboard();
        goDoCommand("cmd_copy");
        goDoCommand("cmd_paste");
        copyToClipboard(backupString);
        content.select();
        content.setSelectionRange(searchResult+lastFindIndex, searchResult+lastFindIndex + findStr.length);

        lastFindIndex = lastFindIndex + searchResult + findStr.length;
        lastFindStr = findStr;
        lastFindIgnoreCase = ignoreCaseStr;

        updateStatus("Find: "+ findStr +"   Result: search successful");
        return true;
    } else {
        lastFindIndex=0;
        doFindAgain();
    }
    return false;
}



// perform find on content area
function doFind(findStr,ignoreCase,isRegex) {
    if (findStr == "") {
        updateStatus("No search string entered.");
        return false;
    }

    var ignoreCaseStr = "";
    var contentStr = content.value;
    
    if (ignoreCase == true) {
        ignoreCaseStr = "i";
    }

    findStr = stripChars(findStr);
    var pattern = new RegExp(findStr, ignoreCaseStr);
    var searchResult = contentStr.search(pattern);

    if (searchResult != -1 ) {
        lastFindIndex = searchResult + findStr.length;
        lastFindStr = findStr;
        lastFindIgnoreCase = ignoreCaseStr;
        
        content.select();
        content.setSelectionRange(searchResult, searchResult + findStr.length);
        
        // copy, paste is scrollTo hack in textbox
        var backupString = getClipboard();
        goDoCommand("cmd_copy");
        goDoCommand("cmd_paste");
        copyToClipboard(backupString);
        
        content.select();
        content.setSelectionRange(searchResult, searchResult + findStr.length);
        updateStatus("Find: "+ findStr +"   Result: search successful");

        return true;
    }
    updateStatus("Find: "+ findStr +"   Result: search unsuccessful");
    return false;
}



// perform find replace on content area
function doReplace(findStr,replaceStr,ignoreCase) {
    var contentStr = content.value;
    var ignoreCaseStr = "";

    if (findStr == "" || replaceStr == "") {
        updateStatus("No search/replace string entered.");
        return false;
    }
    // skip trim if replacing new line chars
    if (findStr.indexOf("\n") == -1) {
        findStr = trim(findStr);
        replaceStr = trim(replaceStr);
    }

    if (ignoreCase == true) {
        ignoreCaseStr = "ig";
    }

    findStr = stripChars(findStr);
    var pattern = new RegExp(findStr, ignoreCaseStr);
    var searchResult = contentStr.search(pattern);

    if (searchResult != -1 ) {
        contentStr = contentStr.replace(pattern, replaceStr);
        copyToClipboard(contentStr);
        content.focus();
        goDoCommand("cmd_selectAll");
        goDoCommand("cmd_paste");

        updateStatus("replace: "+ findStr +"   Result: replace successful");
    } else {
        updateStatus("replace: "+ findStr +"   Result: replace unsuccessful");
    }
}


// increase line spacing
function doIncreaseSpace() {
    var backupString = getClipboard();
    var contentStr = content.value;

    contentStr = contentStr.replace(/\n/g,"\n\n");
    copyToClipboard(contentStr);
    content.focus();
    goDoCommand("cmd_selectAll");
    goDoCommand("cmd_paste");
    updateStatus("Spacing increased...");
}


// decrease line spacing
function doDecreaseSpace() {
    var backupString = getClipboard();
    var contentStr = content.value;

    contentStr = contentStr.replace(/\n\n/g,"\n");
    copyToClipboard(contentStr);
    content.focus();
    goDoCommand("cmd_selectAll");
    goDoCommand("cmd_paste");
    updateStatus("Spacing decreased...");
}


// reverse lines
function doReverseLines() {
    var contentSplit = content.value;
	contentSplit = contentSplit.split("\n");
	contentSplit = contentSplit.reverse();
	contentSplit = contentSplit.join("\n");

	copyToClipboard(contentSplit);
    content.focus();
    goDoCommand("cmd_selectAll");
    goDoCommand("cmd_paste");
	contentSplit = null;
    updateStatus("Reversing lines...");
}

// reverse lines
function doSort() {
    var contentSplit = content.value;
	contentSplit = contentSplit.split("\n");
	contentSplit = contentSplit.sort();
	contentSplit = contentSplit.join("\n");

	copyToClipboard(contentSplit);
    content.focus();
    goDoCommand("cmd_selectAll");
    goDoCommand("cmd_paste");
	contentSplit = null;
    updateStatus("Sorting lines...");
}
